"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Inject = void 0;
require("reflect-metadata");
function Inject(valueToProvide, methodName, parameterIndex) {
    if (parameterIndex === undefined) {
        return function (classConstructor, methodName, parameterIndex) {
            // Set a specific value to provide as a constructor argument
            var typeMetadata = getDiTokens(classConstructor);
            typeMetadata[parameterIndex] = valueToProvide;
            Reflect.defineMetadata('di-tokens', typeMetadata, classConstructor);
        };
    }
    else {
        // Determine the value to provide from the TypeScript metadata
        var classConstructor = valueToProvide;
        var typeMetadata = getDiTokens(classConstructor);
        var paramTypes = Reflect.getMetadata('design:paramtypes', classConstructor);
        if (!paramTypes) {
            throw new Error("InjectionError: No type emitted for parameter " + (parameterIndex + 1) + " of " + classConstructor.name + ".");
        }
        typeMetadata[parameterIndex] = paramTypes[parameterIndex];
        Reflect.defineMetadata('di-tokens', typeMetadata, classConstructor);
    }
}
exports.Inject = Inject;
function getDiTokens(classConstructor) {
    var existing = Reflect.getMetadata('di-tokens', classConstructor)
        || Reflect.getMetadata('design:paramtypes', classConstructor);
    return existing ? existing.slice() : new Array(classConstructor.length);
}
//# sourceMappingURL=inject.js.map