import { Provider, Type } from './provider';
import { InjectionToken } from './injection-token';
export declare class Injector {
    private factories;
    private resolved;
    private parentInjector;
    /**
     * Create a child injector that inherits all factories and resolved values.
     * Providers may be added and dependencies overridden without effecting the parent injector.
     *
     * @param tokensToProvide An array of tokens the child injector should construct locally.
     */
    createChildInjector(tokensToProvide: Array<Type<any> | InjectionToken<any>>): Injector;
    /** Override a dependency token for unit tests */
    overrideDependency(token: Type<any> | InjectionToken<any>, value: any): void;
    get<T extends Type<any>>(token: T): InstanceType<T>;
    get<T>(token: InjectionToken<T>): T;
    get<T extends Type<any>, U>(token: T, notFoundValue: U): InstanceType<T> | U;
    get<T, U>(token: InjectionToken<T>, notFoundValue: U): T | U;
    static isValidProvider(input: any): input is Provider<any>;
    /**
     * Resolve the all dependencies of the passed providers as dependency tree
     * and return an injector that creates and returns instances of the dependencies.
     *
     * All classes that are not explicitly provided are resolved to the class itself,
     * missing InjectionToken providers throw an exception.
     *
     * @example
     *     const injector = Injector.autoResolveAndCreate([App]);
     */
    static autoResolveAndCreate(providers: Provider<any>[]): Injector;
    /**
     * Resolve the passed providers as dependency tree and return an injector
     * that creates and returns instances of the dependencies.
     *
     * Providers for all nested dependencies need to be in the input array.
     *
     * @example
     *     const injector = Injector.resolveAndCreate([App, Dependency1, Dependency2]);
     */
    static resolveAndCreate(providers: Provider<any>[]): Injector;
}
